Class: ArgoWorkflows::IoArgoprojEventsV1alpha1PulsarEventSource

Inherits:
Object
  • Object
show all
Defined in:
lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IoArgoprojEventsV1alpha1PulsarEventSource

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 87

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'authAthenzParams')
    if (value = attributes[:'authAthenzParams']).is_a?(Hash)
      self.auth_athenz_params = value
    end
  end

  if attributes.has_key?(:'authAthenzSecret')
    self.auth_athenz_secret = attributes[:'authAthenzSecret']
  end

  if attributes.has_key?(:'authTokenSecret')
    self.auth_token_secret = attributes[:'authTokenSecret']
  end

  if attributes.has_key?(:'connectionBackoff')
    self.connection_backoff = attributes[:'connectionBackoff']
  end

  if attributes.has_key?(:'filter')
    self.filter = attributes[:'filter']
  end

  if attributes.has_key?(:'jsonBody')
    self.json_body = attributes[:'jsonBody']
  end

  if attributes.has_key?(:'metadata')
    if (value = attributes[:'metadata']).is_a?(Hash)
      self. = value
    end
  end

  if attributes.has_key?(:'tls')
    self.tls = attributes[:'tls']
  end

  if attributes.has_key?(:'tlsAllowInsecureConnection')
    self.tls_allow_insecure_connection = attributes[:'tlsAllowInsecureConnection']
  end

  if attributes.has_key?(:'tlsTrustCertsSecret')
    self.tls_trust_certs_secret = attributes[:'tlsTrustCertsSecret']
  end

  if attributes.has_key?(:'tlsValidateHostname')
    self.tls_validate_hostname = attributes[:'tlsValidateHostname']
  end

  if attributes.has_key?(:'topics')
    if (value = attributes[:'topics']).is_a?(Array)
      self.topics = value
    end
  end

  if attributes.has_key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.has_key?(:'url')
    self.url = attributes[:'url']
  end
end

Instance Attribute Details

#auth_athenz_paramsObject

Returns the value of attribute auth_athenz_params.



17
18
19
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 17

def auth_athenz_params
  @auth_athenz_params
end

#auth_athenz_secretObject

Returns the value of attribute auth_athenz_secret.



19
20
21
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 19

def auth_athenz_secret
  @auth_athenz_secret
end

#auth_token_secretObject

Returns the value of attribute auth_token_secret.



21
22
23
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 21

def auth_token_secret
  @auth_token_secret
end

#connection_backoffObject

Returns the value of attribute connection_backoff.



23
24
25
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 23

def connection_backoff
  @connection_backoff
end

#filterObject

Returns the value of attribute filter.



25
26
27
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 25

def filter
  @filter
end

#json_bodyObject

Returns the value of attribute json_body.



27
28
29
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 27

def json_body
  @json_body
end

#metadataObject

Returns the value of attribute metadata.



29
30
31
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 29

def 
  
end

#tlsObject

Returns the value of attribute tls.



31
32
33
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 31

def tls
  @tls
end

#tls_allow_insecure_connectionObject

Returns the value of attribute tls_allow_insecure_connection.



33
34
35
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 33

def tls_allow_insecure_connection
  @tls_allow_insecure_connection
end

#tls_trust_certs_secretObject

Returns the value of attribute tls_trust_certs_secret.



35
36
37
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 35

def tls_trust_certs_secret
  @tls_trust_certs_secret
end

#tls_validate_hostnameObject

Returns the value of attribute tls_validate_hostname.



37
38
39
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 37

def tls_validate_hostname
  @tls_validate_hostname
end

#topicsObject

Returns the value of attribute topics.



39
40
41
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 39

def topics
  @topics
end

#typeObject

Returns the value of attribute type.



41
42
43
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 41

def type
  @type
end

#urlObject

Returns the value of attribute url.



43
44
45
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 43

def url
  @url
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 46

def self.attribute_map
  {
    :'auth_athenz_params' => :'authAthenzParams',
    :'auth_athenz_secret' => :'authAthenzSecret',
    :'auth_token_secret' => :'authTokenSecret',
    :'connection_backoff' => :'connectionBackoff',
    :'filter' => :'filter',
    :'json_body' => :'jsonBody',
    :'metadata' => :'metadata',
    :'tls' => :'tls',
    :'tls_allow_insecure_connection' => :'tlsAllowInsecureConnection',
    :'tls_trust_certs_secret' => :'tlsTrustCertsSecret',
    :'tls_validate_hostname' => :'tlsValidateHostname',
    :'topics' => :'topics',
    :'type' => :'type',
    :'url' => :'url'
  }
end

.swagger_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 66

def self.swagger_types
  {
    :'auth_athenz_params' => :'Hash<String, String>',
    :'auth_athenz_secret' => :'IoK8sApiCoreV1SecretKeySelector',
    :'auth_token_secret' => :'IoK8sApiCoreV1SecretKeySelector',
    :'connection_backoff' => :'IoArgoprojEventsV1alpha1Backoff',
    :'filter' => :'IoArgoprojEventsV1alpha1EventSourceFilter',
    :'json_body' => :'BOOLEAN',
    :'metadata' => :'Hash<String, String>',
    :'tls' => :'IoArgoprojEventsV1alpha1TLSConfig',
    :'tls_allow_insecure_connection' => :'BOOLEAN',
    :'tls_trust_certs_secret' => :'IoK8sApiCoreV1SecretKeySelector',
    :'tls_validate_hostname' => :'BOOLEAN',
    :'topics' => :'Array<String>',
    :'type' => :'String',
    :'url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auth_athenz_params == o.auth_athenz_params &&
      auth_athenz_secret == o.auth_athenz_secret &&
      auth_token_secret == o.auth_token_secret &&
      connection_backoff == o.connection_backoff &&
      filter == o.filter &&
      json_body == o.json_body &&
       == o. &&
      tls == o.tls &&
      tls_allow_insecure_connection == o.tls_allow_insecure_connection &&
      tls_trust_certs_secret == o.tls_trust_certs_secret &&
      tls_validate_hostname == o.tls_validate_hostname &&
      topics == o.topics &&
      type == o.type &&
      url == o.url
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 226

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = ArgoWorkflows.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 292

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 205

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


192
193
194
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 192

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



198
199
200
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 198

def hash
  [auth_athenz_params, auth_athenz_secret, auth_token_secret, connection_backoff, filter, json_body, , tls, tls_allow_insecure_connection, tls_trust_certs_secret, tls_validate_hostname, topics, type, url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



158
159
160
161
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 158

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



272
273
274
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 272

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



266
267
268
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 266

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
# File 'lib/argo_workflows/models/io_argoproj_events_v1alpha1_pulsar_event_source.rb', line 165

def valid?
  true
end