Class: ArgoWorkflows::IoArgoprojWorkflowV1alpha1CronWorkflowSpec
- Inherits:
-
Object
- Object
- ArgoWorkflows::IoArgoprojWorkflowV1alpha1CronWorkflowSpec
- Defined in:
- lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb
Overview
CronWorkflowSpec is the specification of a CronWorkflow
Instance Attribute Summary collapse
-
#_when ⇒ Object
v3.6 and after: When is an expression that determines if a run should be scheduled.
-
#concurrency_policy ⇒ Object
ConcurrencyPolicy is the K8s-style concurrency policy that will be used.
-
#failed_jobs_history_limit ⇒ Object
FailedJobsHistoryLimit is the number of failed jobs to be kept at a time.
-
#schedule ⇒ Object
Schedule is a schedule to run the Workflow in Cron format.
-
#schedules ⇒ Object
v3.6 and after: Schedules is a list of schedules to run the Workflow in Cron format.
-
#starting_deadline_seconds ⇒ Object
StartingDeadlineSeconds is the K8s-style deadline that will limit the time a CronWorkflow will be run after its original scheduled time if it is missed.
-
#stop_strategy ⇒ Object
v3.6 and after: StopStrategy defines if the CronWorkflow should stop scheduling based on a condition.
-
#successful_jobs_history_limit ⇒ Object
SuccessfulJobsHistoryLimit is the number of successful jobs to be kept at a time.
-
#suspend ⇒ Object
Suspend is a flag that will stop new CronWorkflows from running if set to true.
-
#timezone ⇒ Object
Timezone is the timezone against which the cron schedule will be calculated, e.g.
-
#workflow_metadata ⇒ Object
WorkflowMetadata contains some metadata of the workflow to be run.
-
#workflow_spec ⇒ Object
WorkflowSpec is the spec of the workflow to be run.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1CronWorkflowSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1CronWorkflowSpec
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'concurrencyPolicy') self.concurrency_policy = attributes[:'concurrencyPolicy'] end if attributes.has_key?(:'failedJobsHistoryLimit') self.failed_jobs_history_limit = attributes[:'failedJobsHistoryLimit'] end if attributes.has_key?(:'schedule') self.schedule = attributes[:'schedule'] end if attributes.has_key?(:'schedules') if (value = attributes[:'schedules']).is_a?(Array) self.schedules = value end end if attributes.has_key?(:'startingDeadlineSeconds') self.starting_deadline_seconds = attributes[:'startingDeadlineSeconds'] end if attributes.has_key?(:'stopStrategy') self.stop_strategy = attributes[:'stopStrategy'] end if attributes.has_key?(:'successfulJobsHistoryLimit') self.successful_jobs_history_limit = attributes[:'successfulJobsHistoryLimit'] end if attributes.has_key?(:'suspend') self.suspend = attributes[:'suspend'] end if attributes.has_key?(:'timezone') self.timezone = attributes[:'timezone'] end if attributes.has_key?(:'when') self._when = attributes[:'when'] end if attributes.has_key?(:'workflowMetadata') self. = attributes[:'workflowMetadata'] end if attributes.has_key?(:'workflowSpec') self.workflow_spec = attributes[:'workflowSpec'] end end |
Instance Attribute Details
#_when ⇒ Object
v3.6 and after: When is an expression that determines if a run should be scheduled.
46 47 48 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 46 def _when @_when end |
#concurrency_policy ⇒ Object
ConcurrencyPolicy is the K8s-style concurrency policy that will be used
19 20 21 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 19 def concurrency_policy @concurrency_policy end |
#failed_jobs_history_limit ⇒ Object
FailedJobsHistoryLimit is the number of failed jobs to be kept at a time
22 23 24 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 22 def failed_jobs_history_limit @failed_jobs_history_limit end |
#schedule ⇒ Object
Schedule is a schedule to run the Workflow in Cron format. Deprecated, use Schedules
25 26 27 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 25 def schedule @schedule end |
#schedules ⇒ Object
v3.6 and after: Schedules is a list of schedules to run the Workflow in Cron format
28 29 30 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 28 def schedules @schedules end |
#starting_deadline_seconds ⇒ Object
StartingDeadlineSeconds is the K8s-style deadline that will limit the time a CronWorkflow will be run after its original scheduled time if it is missed.
31 32 33 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 31 def starting_deadline_seconds @starting_deadline_seconds end |
#stop_strategy ⇒ Object
v3.6 and after: StopStrategy defines if the CronWorkflow should stop scheduling based on a condition
34 35 36 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 34 def stop_strategy @stop_strategy end |
#successful_jobs_history_limit ⇒ Object
SuccessfulJobsHistoryLimit is the number of successful jobs to be kept at a time
37 38 39 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 37 def successful_jobs_history_limit @successful_jobs_history_limit end |
#suspend ⇒ Object
Suspend is a flag that will stop new CronWorkflows from running if set to true
40 41 42 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 40 def suspend @suspend end |
#timezone ⇒ Object
Timezone is the timezone against which the cron schedule will be calculated, e.g. "Asia/Tokyo". Default is machine’s local time.
43 44 45 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 43 def timezone @timezone end |
#workflow_metadata ⇒ Object
WorkflowMetadata contains some metadata of the workflow to be run
49 50 51 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 49 def @workflow_metadata end |
#workflow_spec ⇒ Object
WorkflowSpec is the spec of the workflow to be run
52 53 54 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 52 def workflow_spec @workflow_spec end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 55 def self.attribute_map { :'concurrency_policy' => :'concurrencyPolicy', :'failed_jobs_history_limit' => :'failedJobsHistoryLimit', :'schedule' => :'schedule', :'schedules' => :'schedules', :'starting_deadline_seconds' => :'startingDeadlineSeconds', :'stop_strategy' => :'stopStrategy', :'successful_jobs_history_limit' => :'successfulJobsHistoryLimit', :'suspend' => :'suspend', :'timezone' => :'timezone', :'_when' => :'when', :'workflow_metadata' => :'workflowMetadata', :'workflow_spec' => :'workflowSpec' } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 73 def self.swagger_types { :'concurrency_policy' => :'String', :'failed_jobs_history_limit' => :'Integer', :'schedule' => :'String', :'schedules' => :'Array<String>', :'starting_deadline_seconds' => :'Integer', :'stop_strategy' => :'IoArgoprojWorkflowV1alpha1StopStrategy', :'successful_jobs_history_limit' => :'Integer', :'suspend' => :'BOOLEAN', :'timezone' => :'String', :'_when' => :'String', :'workflow_metadata' => :'IoK8sApimachineryPkgApisMetaV1ObjectMeta', :'workflow_spec' => :'IoArgoprojWorkflowV1alpha1WorkflowSpec' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 169 def ==(o) return true if self.equal?(o) self.class == o.class && concurrency_policy == o.concurrency_policy && failed_jobs_history_limit == o.failed_jobs_history_limit && schedule == o.schedule && schedules == o.schedules && starting_deadline_seconds == o.starting_deadline_seconds && stop_strategy == o.stop_strategy && successful_jobs_history_limit == o.successful_jobs_history_limit && suspend == o.suspend && timezone == o.timezone && _when == o._when && == o. && workflow_spec == o.workflow_spec end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 222 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = ArgoWorkflows.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 288 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 201 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 194 def hash [concurrency_policy, failed_jobs_history_limit, schedule, schedules, starting_deadline_seconds, stop_strategy, successful_jobs_history_limit, suspend, timezone, _when, , workflow_spec].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
151 152 153 154 155 156 157 158 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 151 def list_invalid_properties invalid_properties = Array.new if @workflow_spec.nil? invalid_properties.push('invalid value for "workflow_spec", workflow_spec cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
268 269 270 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 268 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
274 275 276 277 278 279 280 281 282 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 274 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
262 263 264 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 262 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_cron_workflow_spec.rb', line 162 def valid? return false if @workflow_spec.nil? true end |