Class: ArgoWorkflows::IoArgoprojWorkflowV1alpha1DAGTask

Inherits:
Object
  • Object
show all
Defined in:
lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb

Overview

DAGTask represents a node in the graph during DAG execution

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1DAGTask

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 102

def initialize(attributes = {})
  return unless attributes.is_a?(Hash)

  # convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v }

  if attributes.has_key?(:'arguments')
    self.arguments = attributes[:'arguments']
  end

  if attributes.has_key?(:'continueOn')
    self.continue_on = attributes[:'continueOn']
  end

  if attributes.has_key?(:'dependencies')
    if (value = attributes[:'dependencies']).is_a?(Array)
      self.dependencies = value
    end
  end

  if attributes.has_key?(:'depends')
    self.depends = attributes[:'depends']
  end

  if attributes.has_key?(:'hooks')
    if (value = attributes[:'hooks']).is_a?(Hash)
      self.hooks = value
    end
  end

  if attributes.has_key?(:'inline')
    self.inline = attributes[:'inline']
  end

  if attributes.has_key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.has_key?(:'onExit')
    self.on_exit = attributes[:'onExit']
  end

  if attributes.has_key?(:'template')
    self.template = attributes[:'template']
  end

  if attributes.has_key?(:'templateRef')
    self.template_ref = attributes[:'templateRef']
  end

  if attributes.has_key?(:'when')
    self._when = attributes[:'when']
  end

  if attributes.has_key?(:'withItems')
    if (value = attributes[:'withItems']).is_a?(Array)
      self.with_items = value
    end
  end

  if attributes.has_key?(:'withParam')
    self.with_param = attributes[:'withParam']
  end

  if attributes.has_key?(:'withSequence')
    self.with_sequence = attributes[:'withSequence']
  end
end

Instance Attribute Details

#_whenObject

When is an expression in which the task should conditionally execute



49
50
51
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 49

def _when
  @_when
end

#argumentsObject

Arguments are the parameter and artifact arguments to the template



19
20
21
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 19

def arguments
  @arguments
end

#continue_onObject

ContinueOn makes argo to proceed with the following step even if this step fails. Errors and Failed states can be specified



22
23
24
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 22

def continue_on
  @continue_on
end

#dependenciesObject

Dependencies are name of other targets which this depends on



25
26
27
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 25

def dependencies
  @dependencies
end

#dependsObject

Depends are name of other targets which this depends on



28
29
30
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 28

def depends
  @depends
end

#hooksObject

Hooks hold the lifecycle hook which is invoked at lifecycle of task, irrespective of the success, failure, or error status of the primary task



31
32
33
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 31

def hooks
  @hooks
end

#inlineObject

Inline is the template. Template must be empty if this is declared (and vice-versa). Note: As mentioned in the corresponding definition in WorkflowStep, this struct is defined recursively, so we need "x-kubernetes-preserve-unknown-fields: true" in the validation schema.



34
35
36
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 34

def inline
  @inline
end

#nameObject

Name is the name of the target



37
38
39
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 37

def name
  @name
end

#on_exitObject

OnExit is a template reference which is invoked at the end of the template, irrespective of the success, failure, or error of the primary template. DEPRECATED: Use Hooks.Template instead.



40
41
42
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 40

def on_exit
  @on_exit
end

#templateObject

Name of template to execute



43
44
45
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 43

def template
  @template
end

#template_refObject

TemplateRef is the reference to the template resource to execute.



46
47
48
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 46

def template_ref
  @template_ref
end

#with_itemsObject

WithItems expands a task into multiple parallel tasks from the items in the list Note: The structure of WithItems is free-form, so we need "x-kubernetes-preserve-unknown-fields: true" in the validation schema.



52
53
54
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 52

def with_items
  @with_items
end

#with_paramObject

WithParam expands a task into multiple parallel tasks from the value in the parameter, which is expected to be a JSON list.



55
56
57
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 55

def with_param
  @with_param
end

#with_sequenceObject

WithSequence expands a task into a numeric sequence



58
59
60
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 58

def with_sequence
  @with_sequence
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 61

def self.attribute_map
  {
    :'arguments' => :'arguments',
    :'continue_on' => :'continueOn',
    :'dependencies' => :'dependencies',
    :'depends' => :'depends',
    :'hooks' => :'hooks',
    :'inline' => :'inline',
    :'name' => :'name',
    :'on_exit' => :'onExit',
    :'template' => :'template',
    :'template_ref' => :'templateRef',
    :'_when' => :'when',
    :'with_items' => :'withItems',
    :'with_param' => :'withParam',
    :'with_sequence' => :'withSequence'
  }
end

.swagger_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 81

def self.swagger_types
  {
    :'arguments' => :'IoArgoprojWorkflowV1alpha1Arguments',
    :'continue_on' => :'IoArgoprojWorkflowV1alpha1ContinueOn',
    :'dependencies' => :'Array<String>',
    :'depends' => :'String',
    :'hooks' => :'Hash<String, IoArgoprojWorkflowV1alpha1LifecycleHook>',
    :'inline' => :'IoArgoprojWorkflowV1alpha1Template',
    :'name' => :'String',
    :'on_exit' => :'String',
    :'template' => :'String',
    :'template_ref' => :'IoArgoprojWorkflowV1alpha1TemplateRef',
    :'_when' => :'String',
    :'with_items' => :'Array<IoArgoprojWorkflowV1alpha1Item>',
    :'with_param' => :'String',
    :'with_sequence' => :'IoArgoprojWorkflowV1alpha1Sequence'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      arguments == o.arguments &&
      continue_on == o.continue_on &&
      dependencies == o.dependencies &&
      depends == o.depends &&
      hooks == o.hooks &&
      inline == o.inline &&
      name == o.name &&
      on_exit == o.on_exit &&
      template == o.template &&
      template_ref == o.template_ref &&
      _when == o._when &&
      with_items == o.with_items &&
      with_param == o.with_param &&
      with_sequence == o.with_sequence
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 246

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :BOOLEAN
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    temp_model = ArgoWorkflows.const_get(type).new
    temp_model.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



312
313
314
315
316
317
318
319
320
321
322
323
324
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 312

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 225

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.swagger_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 212

def eql?(o)
  self == o
end

#hashFixnum

Calculates hash code according to all attributes.

Returns:

  • (Fixnum)

    Hash code



218
219
220
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 218

def hash
  [arguments, continue_on, dependencies, depends, hooks, inline, name, on_exit, template, template_ref, _when, with_items, with_param, with_sequence].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 173

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 292

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    next if value.nil?
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



286
287
288
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 286

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_dag_task.rb', line 184

def valid?
  return false if @name.nil?
  true
end