Class: ArgoWorkflows::IoArgoprojWorkflowV1alpha1S3ArtifactRepository
- Inherits:
-
Object
- Object
- ArgoWorkflows::IoArgoprojWorkflowV1alpha1S3ArtifactRepository
- Defined in:
- lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb
Overview
S3ArtifactRepository defines the controller configuration for an S3 artifact repository
Instance Attribute Summary collapse
-
#access_key_secret ⇒ Object
AccessKeySecret is the secret selector to the bucket’s access key.
-
#bucket ⇒ Object
Bucket is the name of the bucket.
-
#ca_secret ⇒ Object
CASecret specifies the secret that contains the CA, used to verify the TLS connection.
-
#create_bucket_if_not_present ⇒ Object
CreateBucketIfNotPresent tells the driver to attempt to create the S3 bucket for output artifacts, if it doesn’t exist.
-
#encryption_options ⇒ Object
Returns the value of attribute encryption_options.
-
#endpoint ⇒ Object
Endpoint is the hostname of the bucket endpoint.
-
#insecure ⇒ Object
Insecure will connect to the service with TLS.
-
#key_format ⇒ Object
KeyFormat defines the format of how to store keys and can reference workflow variables.
-
#key_prefix ⇒ Object
KeyPrefix is prefix used as part of the bucket key in which the controller will store artifacts.
-
#region ⇒ Object
Region contains the optional bucket region.
-
#role_arn ⇒ Object
RoleARN is the Amazon Resource Name (ARN) of the role to assume.
-
#secret_key_secret ⇒ Object
SecretKeySecret is the secret selector to the bucket’s secret key.
-
#session_token_secret ⇒ Object
SessionTokenSecret is used for ephemeral credentials like an IAM assume role or S3 access grant.
-
#use_sdk_creds ⇒ Object
UseSDKCreds tells the driver to figure out credentials based on sdk defaults.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1S3ArtifactRepository
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1S3ArtifactRepository
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 101 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'accessKeySecret') self.access_key_secret = attributes[:'accessKeySecret'] end if attributes.has_key?(:'bucket') self.bucket = attributes[:'bucket'] end if attributes.has_key?(:'caSecret') self.ca_secret = attributes[:'caSecret'] end if attributes.has_key?(:'createBucketIfNotPresent') self.create_bucket_if_not_present = attributes[:'createBucketIfNotPresent'] end if attributes.has_key?(:'encryptionOptions') self. = attributes[:'encryptionOptions'] end if attributes.has_key?(:'endpoint') self.endpoint = attributes[:'endpoint'] end if attributes.has_key?(:'insecure') self.insecure = attributes[:'insecure'] end if attributes.has_key?(:'keyFormat') self.key_format = attributes[:'keyFormat'] end if attributes.has_key?(:'keyPrefix') self.key_prefix = attributes[:'keyPrefix'] end if attributes.has_key?(:'region') self.region = attributes[:'region'] end if attributes.has_key?(:'roleARN') self.role_arn = attributes[:'roleARN'] end if attributes.has_key?(:'secretKeySecret') self.secret_key_secret = attributes[:'secretKeySecret'] end if attributes.has_key?(:'sessionTokenSecret') self.session_token_secret = attributes[:'sessionTokenSecret'] end if attributes.has_key?(:'useSDKCreds') self.use_sdk_creds = attributes[:'useSDKCreds'] end end |
Instance Attribute Details
#access_key_secret ⇒ Object
AccessKeySecret is the secret selector to the bucket’s access key
19 20 21 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 19 def access_key_secret @access_key_secret end |
#bucket ⇒ Object
Bucket is the name of the bucket
22 23 24 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 22 def bucket @bucket end |
#ca_secret ⇒ Object
CASecret specifies the secret that contains the CA, used to verify the TLS connection
25 26 27 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 25 def ca_secret @ca_secret end |
#create_bucket_if_not_present ⇒ Object
CreateBucketIfNotPresent tells the driver to attempt to create the S3 bucket for output artifacts, if it doesn’t exist. Setting Enabled Encryption will apply either SSE-S3 to the bucket if KmsKeyId is not set or SSE-KMS if it is.
28 29 30 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 28 def create_bucket_if_not_present @create_bucket_if_not_present end |
#encryption_options ⇒ Object
Returns the value of attribute encryption_options.
30 31 32 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 30 def end |
#endpoint ⇒ Object
Endpoint is the hostname of the bucket endpoint
33 34 35 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 33 def endpoint @endpoint end |
#insecure ⇒ Object
Insecure will connect to the service with TLS
36 37 38 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 36 def insecure @insecure end |
#key_format ⇒ Object
KeyFormat defines the format of how to store keys and can reference workflow variables.
39 40 41 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 39 def key_format @key_format end |
#key_prefix ⇒ Object
KeyPrefix is prefix used as part of the bucket key in which the controller will store artifacts. DEPRECATED. Use KeyFormat instead
42 43 44 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 42 def key_prefix @key_prefix end |
#region ⇒ Object
Region contains the optional bucket region
45 46 47 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 45 def region @region end |
#role_arn ⇒ Object
RoleARN is the Amazon Resource Name (ARN) of the role to assume.
48 49 50 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 48 def role_arn @role_arn end |
#secret_key_secret ⇒ Object
SecretKeySecret is the secret selector to the bucket’s secret key
51 52 53 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 51 def secret_key_secret @secret_key_secret end |
#session_token_secret ⇒ Object
SessionTokenSecret is used for ephemeral credentials like an IAM assume role or S3 access grant
54 55 56 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 54 def session_token_secret @session_token_secret end |
#use_sdk_creds ⇒ Object
UseSDKCreds tells the driver to figure out credentials based on sdk defaults.
57 58 59 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 57 def use_sdk_creds @use_sdk_creds end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 60 def self.attribute_map { :'access_key_secret' => :'accessKeySecret', :'bucket' => :'bucket', :'ca_secret' => :'caSecret', :'create_bucket_if_not_present' => :'createBucketIfNotPresent', :'encryption_options' => :'encryptionOptions', :'endpoint' => :'endpoint', :'insecure' => :'insecure', :'key_format' => :'keyFormat', :'key_prefix' => :'keyPrefix', :'region' => :'region', :'role_arn' => :'roleARN', :'secret_key_secret' => :'secretKeySecret', :'session_token_secret' => :'sessionTokenSecret', :'use_sdk_creds' => :'useSDKCreds' } end |
.swagger_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 80 def self.swagger_types { :'access_key_secret' => :'IoK8sApiCoreV1SecretKeySelector', :'bucket' => :'String', :'ca_secret' => :'IoK8sApiCoreV1SecretKeySelector', :'create_bucket_if_not_present' => :'IoArgoprojWorkflowV1alpha1CreateS3BucketOptions', :'encryption_options' => :'IoArgoprojWorkflowV1alpha1S3EncryptionOptions', :'endpoint' => :'String', :'insecure' => :'BOOLEAN', :'key_format' => :'String', :'key_prefix' => :'String', :'region' => :'String', :'role_arn' => :'String', :'secret_key_secret' => :'IoK8sApiCoreV1SecretKeySelector', :'session_token_secret' => :'IoK8sApiCoreV1SecretKeySelector', :'use_sdk_creds' => :'BOOLEAN' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 179 def ==(o) return true if self.equal?(o) self.class == o.class && access_key_secret == o.access_key_secret && bucket == o.bucket && ca_secret == o.ca_secret && create_bucket_if_not_present == o.create_bucket_if_not_present && == o. && endpoint == o.endpoint && insecure == o.insecure && key_format == o.key_format && key_prefix == o.key_prefix && region == o.region && role_arn == o.role_arn && secret_key_secret == o.secret_key_secret && session_token_secret == o.session_token_secret && use_sdk_creds == o.use_sdk_creds end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 234 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = ArgoWorkflows.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 300 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 213 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
200 201 202 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 200 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
206 207 208 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 206 def hash [access_key_secret, bucket, ca_secret, create_bucket_if_not_present, , endpoint, insecure, key_format, key_prefix, region, role_arn, secret_key_secret, session_token_secret, use_sdk_creds].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 166 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
280 281 282 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 280 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
274 275 276 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 274 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_s3_artifact_repository.rb', line 173 def valid? true end |