Class: ArgoWorkflows::IoArgoprojWorkflowV1alpha1WorkflowSpec
- Inherits:
-
Object
- Object
- ArgoWorkflows::IoArgoprojWorkflowV1alpha1WorkflowSpec
- Defined in:
- lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb
Overview
WorkflowSpec is the specification of a Workflow.
Instance Attribute Summary collapse
-
#active_deadline_seconds ⇒ Object
Optional duration in seconds relative to the workflow start time which the workflow is allowed to run before the controller terminates the io.argoproj.workflow.v1alpha1.
-
#affinity ⇒ Object
Affinity sets the scheduling constraints for all pods in the io.argoproj.workflow.v1alpha1.
-
#archive_logs ⇒ Object
ArchiveLogs indicates if the container logs should be archived.
-
#arguments ⇒ Object
Arguments contain the parameters and artifacts sent to the workflow entrypoint Parameters are referencable globally using the ‘workflow’ variable prefix.
-
#artifact_gc ⇒ Object
ArtifactGC describes the strategy to use when deleting artifacts from completed or deleted workflows (applies to all output Artifacts unless Artifact.ArtifactGC is specified, which overrides this).
-
#artifact_repository_ref ⇒ Object
ArtifactRepositoryRef specifies the configMap name and key containing the artifact repository config.
-
#automount_service_account_token ⇒ Object
AutomountServiceAccountToken indicates whether a service account token should be automatically mounted in pods.
-
#dns_config ⇒ Object
PodDNSConfig defines the DNS parameters of a pod in addition to those generated from DNSPolicy.
-
#dns_policy ⇒ Object
Set DNS policy for workflow pods.
-
#entrypoint ⇒ Object
Entrypoint is a template reference to the starting point of the io.argoproj.workflow.v1alpha1.
-
#executor ⇒ Object
Executor holds configurations of executor containers of the io.argoproj.workflow.v1alpha1.
-
#hooks ⇒ Object
Hooks holds the lifecycle hook which is invoked at lifecycle of step, irrespective of the success, failure, or error status of the primary step.
-
#host_aliases ⇒ Object
Returns the value of attribute host_aliases.
-
#host_network ⇒ Object
Host networking requested for this workflow pod.
-
#image_pull_secrets ⇒ Object
ImagePullSecrets is a list of references to secrets in the same namespace to use for pulling any images in pods that reference this ServiceAccount.
-
#metrics ⇒ Object
Metrics are a list of metrics emitted from this Workflow.
-
#node_selector ⇒ Object
NodeSelector is a selector which will result in all pods of the workflow to be scheduled on the selected node(s).
-
#on_exit ⇒ Object
OnExit is a template reference which is invoked at the end of the workflow, irrespective of the success, failure, or error of the primary io.argoproj.workflow.v1alpha1.
-
#parallelism ⇒ Object
Parallelism limits the max total parallel pods that can execute at the same time in a workflow.
-
#pod_disruption_budget ⇒ Object
PodDisruptionBudget holds the number of concurrent disruptions that you allow for Workflow’s Pods.
-
#pod_gc ⇒ Object
PodGC describes the strategy to use when deleting completed pods.
-
#pod_metadata ⇒ Object
PodMetadata defines additional metadata that should be applied to workflow pods.
-
#pod_priority ⇒ Object
Priority to apply to workflow pods.
-
#pod_priority_class_name ⇒ Object
PriorityClassName to apply to workflow pods.
-
#pod_spec_patch ⇒ Object
PodSpecPatch holds strategic merge patch to apply against the pod spec.
-
#priority ⇒ Object
Priority is used if controller is configured to process limited number of workflows in parallel.
-
#retry_strategy ⇒ Object
RetryStrategy for all templates in the io.argoproj.workflow.v1alpha1.
-
#scheduler_name ⇒ Object
Set scheduler name for all pods.
-
#security_context ⇒ Object
SecurityContext holds pod-level security attributes and common container settings.
-
#service_account_name ⇒ Object
ServiceAccountName is the name of the ServiceAccount to run all pods of the workflow as.
-
#shutdown ⇒ Object
Shutdown will shutdown the workflow according to its ShutdownStrategy.
-
#suspend ⇒ Object
Suspend will suspend the workflow and prevent execution of any future steps in the workflow.
-
#synchronization ⇒ Object
Synchronization holds synchronization lock configuration for this Workflow.
-
#template_defaults ⇒ Object
TemplateDefaults holds default template values that will apply to all templates in the Workflow, unless overridden on the template-level.
-
#templates ⇒ Object
Templates is a list of workflow templates used in a workflow.
-
#tolerations ⇒ Object
Tolerations to apply to workflow pods.
-
#ttl_strategy ⇒ Object
TTLStrategy limits the lifetime of a Workflow that has finished execution depending on if it Succeeded or Failed.
-
#volume_claim_gc ⇒ Object
VolumeClaimGC describes the strategy to use when deleting volumes from completed workflows.
-
#volume_claim_templates ⇒ Object
VolumeClaimTemplates is a list of claims that containers are allowed to reference.
-
#volumes ⇒ Object
Volumes is a list of volumes that can be mounted by containers in a io.argoproj.workflow.v1alpha1.
-
#workflow_metadata ⇒ Object
WorkflowMetadata contains some metadata of the workflow to refer to.
-
#workflow_template_ref ⇒ Object
WorkflowTemplateRef holds a reference to a WorkflowTemplate for execution.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1WorkflowSpec
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1WorkflowSpec
Initializes the object
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 241 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'activeDeadlineSeconds') self.active_deadline_seconds = attributes[:'activeDeadlineSeconds'] end if attributes.has_key?(:'affinity') self.affinity = attributes[:'affinity'] end if attributes.has_key?(:'archiveLogs') self.archive_logs = attributes[:'archiveLogs'] end if attributes.has_key?(:'arguments') self.arguments = attributes[:'arguments'] end if attributes.has_key?(:'artifactGC') self.artifact_gc = attributes[:'artifactGC'] end if attributes.has_key?(:'artifactRepositoryRef') self.artifact_repository_ref = attributes[:'artifactRepositoryRef'] end if attributes.has_key?(:'automountServiceAccountToken') self.automount_service_account_token = attributes[:'automountServiceAccountToken'] end if attributes.has_key?(:'dnsConfig') self.dns_config = attributes[:'dnsConfig'] end if attributes.has_key?(:'dnsPolicy') self.dns_policy = attributes[:'dnsPolicy'] end if attributes.has_key?(:'entrypoint') self.entrypoint = attributes[:'entrypoint'] end if attributes.has_key?(:'executor') self.executor = attributes[:'executor'] end if attributes.has_key?(:'hooks') if (value = attributes[:'hooks']).is_a?(Hash) self.hooks = value end end if attributes.has_key?(:'hostAliases') if (value = attributes[:'hostAliases']).is_a?(Array) self.host_aliases = value end end if attributes.has_key?(:'hostNetwork') self.host_network = attributes[:'hostNetwork'] end if attributes.has_key?(:'imagePullSecrets') if (value = attributes[:'imagePullSecrets']).is_a?(Array) self.image_pull_secrets = value end end if attributes.has_key?(:'metrics') self.metrics = attributes[:'metrics'] end if attributes.has_key?(:'nodeSelector') if (value = attributes[:'nodeSelector']).is_a?(Hash) self.node_selector = value end end if attributes.has_key?(:'onExit') self.on_exit = attributes[:'onExit'] end if attributes.has_key?(:'parallelism') self.parallelism = attributes[:'parallelism'] end if attributes.has_key?(:'podDisruptionBudget') self.pod_disruption_budget = attributes[:'podDisruptionBudget'] end if attributes.has_key?(:'podGC') self.pod_gc = attributes[:'podGC'] end if attributes.has_key?(:'podMetadata') self. = attributes[:'podMetadata'] end if attributes.has_key?(:'podPriority') self.pod_priority = attributes[:'podPriority'] end if attributes.has_key?(:'podPriorityClassName') self.pod_priority_class_name = attributes[:'podPriorityClassName'] end if attributes.has_key?(:'podSpecPatch') self.pod_spec_patch = attributes[:'podSpecPatch'] end if attributes.has_key?(:'priority') self.priority = attributes[:'priority'] end if attributes.has_key?(:'retryStrategy') self.retry_strategy = attributes[:'retryStrategy'] end if attributes.has_key?(:'schedulerName') self.scheduler_name = attributes[:'schedulerName'] end if attributes.has_key?(:'securityContext') self.security_context = attributes[:'securityContext'] end if attributes.has_key?(:'serviceAccountName') self.service_account_name = attributes[:'serviceAccountName'] end if attributes.has_key?(:'shutdown') self.shutdown = attributes[:'shutdown'] end if attributes.has_key?(:'suspend') self.suspend = attributes[:'suspend'] end if attributes.has_key?(:'synchronization') self.synchronization = attributes[:'synchronization'] end if attributes.has_key?(:'templateDefaults') self.template_defaults = attributes[:'templateDefaults'] end if attributes.has_key?(:'templates') if (value = attributes[:'templates']).is_a?(Array) self.templates = value end end if attributes.has_key?(:'tolerations') if (value = attributes[:'tolerations']).is_a?(Array) self.tolerations = value end end if attributes.has_key?(:'ttlStrategy') self.ttl_strategy = attributes[:'ttlStrategy'] end if attributes.has_key?(:'volumeClaimGC') self.volume_claim_gc = attributes[:'volumeClaimGC'] end if attributes.has_key?(:'volumeClaimTemplates') if (value = attributes[:'volumeClaimTemplates']).is_a?(Array) self.volume_claim_templates = value end end if attributes.has_key?(:'volumes') if (value = attributes[:'volumes']).is_a?(Array) self.volumes = value end end if attributes.has_key?(:'workflowMetadata') self. = attributes[:'workflowMetadata'] end if attributes.has_key?(:'workflowTemplateRef') self.workflow_template_ref = attributes[:'workflowTemplateRef'] end end |
Instance Attribute Details
#active_deadline_seconds ⇒ Object
Optional duration in seconds relative to the workflow start time which the workflow is allowed to run before the controller terminates the io.argoproj.workflow.v1alpha1. A value of zero is used to terminate a Running workflow
19 20 21 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 19 def active_deadline_seconds @active_deadline_seconds end |
#affinity ⇒ Object
Affinity sets the scheduling constraints for all pods in the io.argoproj.workflow.v1alpha1. Can be overridden by an affinity specified in the template
22 23 24 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 22 def affinity @affinity end |
#archive_logs ⇒ Object
ArchiveLogs indicates if the container logs should be archived
25 26 27 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 25 def archive_logs @archive_logs end |
#arguments ⇒ Object
Arguments contain the parameters and artifacts sent to the workflow entrypoint Parameters are referencable globally using the ‘workflow’ variable prefix. e.g. ArgoWorkflows::IoArgoprojWorkflowV1alpha1WorkflowSpec.{io{io.argoproj{io.argoproj.workflow{io.argoproj.workflow.v1alpha1{io.argoproj.workflow.v1alpha1.parameters{io.argoproj.workflow.v1alpha1.parameters.myparam}
28 29 30 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 28 def arguments @arguments end |
#artifact_gc ⇒ Object
ArtifactGC describes the strategy to use when deleting artifacts from completed or deleted workflows (applies to all output Artifacts unless Artifact.ArtifactGC is specified, which overrides this)
31 32 33 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 31 def artifact_gc @artifact_gc end |
#artifact_repository_ref ⇒ Object
ArtifactRepositoryRef specifies the configMap name and key containing the artifact repository config.
34 35 36 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 34 def artifact_repository_ref @artifact_repository_ref end |
#automount_service_account_token ⇒ Object
AutomountServiceAccountToken indicates whether a service account token should be automatically mounted in pods. ServiceAccountName of ExecutorConfig must be specified if this value is false.
37 38 39 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 37 def automount_service_account_token @automount_service_account_token end |
#dns_config ⇒ Object
PodDNSConfig defines the DNS parameters of a pod in addition to those generated from DNSPolicy.
40 41 42 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 40 def dns_config @dns_config end |
#dns_policy ⇒ Object
Set DNS policy for workflow pods. Defaults to "ClusterFirst". Valid values are ‘ClusterFirstWithHostNet’, ‘ClusterFirst’, ‘Default’ or ‘None’. DNS parameters given in DNSConfig will be merged with the policy selected with DNSPolicy. To have DNS options set along with hostNetwork, you have to specify DNS policy explicitly to ‘ClusterFirstWithHostNet’.
43 44 45 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 43 def dns_policy @dns_policy end |
#entrypoint ⇒ Object
Entrypoint is a template reference to the starting point of the io.argoproj.workflow.v1alpha1.
46 47 48 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 46 def entrypoint @entrypoint end |
#executor ⇒ Object
Executor holds configurations of executor containers of the io.argoproj.workflow.v1alpha1.
49 50 51 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 49 def executor @executor end |
#hooks ⇒ Object
Hooks holds the lifecycle hook which is invoked at lifecycle of step, irrespective of the success, failure, or error status of the primary step
52 53 54 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 52 def hooks @hooks end |
#host_aliases ⇒ Object
Returns the value of attribute host_aliases.
54 55 56 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 54 def host_aliases @host_aliases end |
#host_network ⇒ Object
Host networking requested for this workflow pod. Default to false.
57 58 59 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 57 def host_network @host_network end |
#image_pull_secrets ⇒ Object
ImagePullSecrets is a list of references to secrets in the same namespace to use for pulling any images in pods that reference this ServiceAccount. ImagePullSecrets are distinct from Secrets because Secrets can be mounted in the pod, but ImagePullSecrets are only accessed by the kubelet. More info: kubernetes.io/docs/concepts/containers/images/#specifying-imagepullsecrets-on-a-pod
60 61 62 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 60 def image_pull_secrets @image_pull_secrets end |
#metrics ⇒ Object
Metrics are a list of metrics emitted from this Workflow
63 64 65 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 63 def metrics @metrics end |
#node_selector ⇒ Object
NodeSelector is a selector which will result in all pods of the workflow to be scheduled on the selected node(s). This is able to be overridden by a nodeSelector specified in the template.
66 67 68 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 66 def node_selector @node_selector end |
#on_exit ⇒ Object
OnExit is a template reference which is invoked at the end of the workflow, irrespective of the success, failure, or error of the primary io.argoproj.workflow.v1alpha1.
69 70 71 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 69 def on_exit @on_exit end |
#parallelism ⇒ Object
Parallelism limits the max total parallel pods that can execute at the same time in a workflow
72 73 74 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 72 def parallelism @parallelism end |
#pod_disruption_budget ⇒ Object
PodDisruptionBudget holds the number of concurrent disruptions that you allow for Workflow’s Pods. Controller will automatically add the selector with workflow name, if selector is empty. Optional: Defaults to empty.
75 76 77 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 75 def pod_disruption_budget @pod_disruption_budget end |
#pod_gc ⇒ Object
PodGC describes the strategy to use when deleting completed pods
78 79 80 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 78 def pod_gc @pod_gc end |
#pod_metadata ⇒ Object
PodMetadata defines additional metadata that should be applied to workflow pods
81 82 83 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 81 def end |
#pod_priority ⇒ Object
Priority to apply to workflow pods. DEPRECATED: Use PodPriorityClassName instead.
84 85 86 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 84 def pod_priority @pod_priority end |
#pod_priority_class_name ⇒ Object
PriorityClassName to apply to workflow pods.
87 88 89 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 87 def pod_priority_class_name @pod_priority_class_name end |
#pod_spec_patch ⇒ Object
PodSpecPatch holds strategic merge patch to apply against the pod spec. Allows parameterization of container fields which are not strings (e.g. resource limits).
90 91 92 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 90 def pod_spec_patch @pod_spec_patch end |
#priority ⇒ Object
Priority is used if controller is configured to process limited number of workflows in parallel. Workflows with higher priority are processed first.
93 94 95 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 93 def priority @priority end |
#retry_strategy ⇒ Object
RetryStrategy for all templates in the io.argoproj.workflow.v1alpha1.
96 97 98 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 96 def retry_strategy @retry_strategy end |
#scheduler_name ⇒ Object
Set scheduler name for all pods. Will be overridden if container/script template’s scheduler name is set. Default scheduler will be used if neither specified.
99 100 101 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 99 def scheduler_name @scheduler_name end |
#security_context ⇒ Object
SecurityContext holds pod-level security attributes and common container settings. Optional: Defaults to empty. See type description for default values of each field.
102 103 104 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 102 def security_context @security_context end |
#service_account_name ⇒ Object
ServiceAccountName is the name of the ServiceAccount to run all pods of the workflow as.
105 106 107 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 105 def service_account_name @service_account_name end |
#shutdown ⇒ Object
Shutdown will shutdown the workflow according to its ShutdownStrategy
108 109 110 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 108 def shutdown @shutdown end |
#suspend ⇒ Object
Suspend will suspend the workflow and prevent execution of any future steps in the workflow
111 112 113 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 111 def suspend @suspend end |
#synchronization ⇒ Object
Synchronization holds synchronization lock configuration for this Workflow
114 115 116 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 114 def synchronization @synchronization end |
#template_defaults ⇒ Object
TemplateDefaults holds default template values that will apply to all templates in the Workflow, unless overridden on the template-level
117 118 119 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 117 def template_defaults @template_defaults end |
#templates ⇒ Object
Templates is a list of workflow templates used in a workflow
120 121 122 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 120 def templates @templates end |
#tolerations ⇒ Object
Tolerations to apply to workflow pods.
123 124 125 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 123 def tolerations @tolerations end |
#ttl_strategy ⇒ Object
TTLStrategy limits the lifetime of a Workflow that has finished execution depending on if it Succeeded or Failed. If this struct is set, once the Workflow finishes, it will be deleted after the time to live expires. If this field is unset, the controller config map will hold the default values.
126 127 128 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 126 def ttl_strategy @ttl_strategy end |
#volume_claim_gc ⇒ Object
VolumeClaimGC describes the strategy to use when deleting volumes from completed workflows
129 130 131 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 129 def volume_claim_gc @volume_claim_gc end |
#volume_claim_templates ⇒ Object
VolumeClaimTemplates is a list of claims that containers are allowed to reference. The Workflow controller will create the claims at the beginning of the workflow and delete the claims upon completion of the workflow
132 133 134 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 132 def volume_claim_templates @volume_claim_templates end |
#volumes ⇒ Object
Volumes is a list of volumes that can be mounted by containers in a io.argoproj.workflow.v1alpha1.
135 136 137 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 135 def volumes @volumes end |
#workflow_metadata ⇒ Object
WorkflowMetadata contains some metadata of the workflow to refer to
138 139 140 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 138 def end |
#workflow_template_ref ⇒ Object
WorkflowTemplateRef holds a reference to a WorkflowTemplate for execution
141 142 143 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 141 def workflow_template_ref @workflow_template_ref end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 144 def self.attribute_map { :'active_deadline_seconds' => :'activeDeadlineSeconds', :'affinity' => :'affinity', :'archive_logs' => :'archiveLogs', :'arguments' => :'arguments', :'artifact_gc' => :'artifactGC', :'artifact_repository_ref' => :'artifactRepositoryRef', :'automount_service_account_token' => :'automountServiceAccountToken', :'dns_config' => :'dnsConfig', :'dns_policy' => :'dnsPolicy', :'entrypoint' => :'entrypoint', :'executor' => :'executor', :'hooks' => :'hooks', :'host_aliases' => :'hostAliases', :'host_network' => :'hostNetwork', :'image_pull_secrets' => :'imagePullSecrets', :'metrics' => :'metrics', :'node_selector' => :'nodeSelector', :'on_exit' => :'onExit', :'parallelism' => :'parallelism', :'pod_disruption_budget' => :'podDisruptionBudget', :'pod_gc' => :'podGC', :'pod_metadata' => :'podMetadata', :'pod_priority' => :'podPriority', :'pod_priority_class_name' => :'podPriorityClassName', :'pod_spec_patch' => :'podSpecPatch', :'priority' => :'priority', :'retry_strategy' => :'retryStrategy', :'scheduler_name' => :'schedulerName', :'security_context' => :'securityContext', :'service_account_name' => :'serviceAccountName', :'shutdown' => :'shutdown', :'suspend' => :'suspend', :'synchronization' => :'synchronization', :'template_defaults' => :'templateDefaults', :'templates' => :'templates', :'tolerations' => :'tolerations', :'ttl_strategy' => :'ttlStrategy', :'volume_claim_gc' => :'volumeClaimGC', :'volume_claim_templates' => :'volumeClaimTemplates', :'volumes' => :'volumes', :'workflow_metadata' => :'workflowMetadata', :'workflow_template_ref' => :'workflowTemplateRef' } end |
.swagger_types ⇒ Object
Attribute type mapping.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 192 def self.swagger_types { :'active_deadline_seconds' => :'Integer', :'affinity' => :'IoK8sApiCoreV1Affinity', :'archive_logs' => :'BOOLEAN', :'arguments' => :'IoArgoprojWorkflowV1alpha1Arguments', :'artifact_gc' => :'IoArgoprojWorkflowV1alpha1WorkflowLevelArtifactGC', :'artifact_repository_ref' => :'IoArgoprojWorkflowV1alpha1ArtifactRepositoryRef', :'automount_service_account_token' => :'BOOLEAN', :'dns_config' => :'IoK8sApiCoreV1PodDNSConfig', :'dns_policy' => :'String', :'entrypoint' => :'String', :'executor' => :'IoArgoprojWorkflowV1alpha1ExecutorConfig', :'hooks' => :'Hash<String, IoArgoprojWorkflowV1alpha1LifecycleHook>', :'host_aliases' => :'Array<IoK8sApiCoreV1HostAlias>', :'host_network' => :'BOOLEAN', :'image_pull_secrets' => :'Array<IoK8sApiCoreV1LocalObjectReference>', :'metrics' => :'IoArgoprojWorkflowV1alpha1Metrics', :'node_selector' => :'Hash<String, String>', :'on_exit' => :'String', :'parallelism' => :'Integer', :'pod_disruption_budget' => :'IoK8sApiPolicyV1PodDisruptionBudgetSpec', :'pod_gc' => :'IoArgoprojWorkflowV1alpha1PodGC', :'pod_metadata' => :'IoArgoprojWorkflowV1alpha1Metadata', :'pod_priority' => :'Integer', :'pod_priority_class_name' => :'String', :'pod_spec_patch' => :'String', :'priority' => :'Integer', :'retry_strategy' => :'IoArgoprojWorkflowV1alpha1RetryStrategy', :'scheduler_name' => :'String', :'security_context' => :'IoK8sApiCoreV1PodSecurityContext', :'service_account_name' => :'String', :'shutdown' => :'String', :'suspend' => :'BOOLEAN', :'synchronization' => :'IoArgoprojWorkflowV1alpha1Synchronization', :'template_defaults' => :'IoArgoprojWorkflowV1alpha1Template', :'templates' => :'Array<IoArgoprojWorkflowV1alpha1Template>', :'tolerations' => :'Array<IoK8sApiCoreV1Toleration>', :'ttl_strategy' => :'IoArgoprojWorkflowV1alpha1TTLStrategy', :'volume_claim_gc' => :'IoArgoprojWorkflowV1alpha1VolumeClaimGC', :'volume_claim_templates' => :'Array<IoK8sApiCoreV1PersistentVolumeClaim>', :'volumes' => :'Array<IoK8sApiCoreV1Volume>', :'workflow_metadata' => :'IoArgoprojWorkflowV1alpha1WorkflowMetadata', :'workflow_template_ref' => :'IoArgoprojWorkflowV1alpha1WorkflowTemplateRef' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 447 def ==(o) return true if self.equal?(o) self.class == o.class && active_deadline_seconds == o.active_deadline_seconds && affinity == o.affinity && archive_logs == o.archive_logs && arguments == o.arguments && artifact_gc == o.artifact_gc && artifact_repository_ref == o.artifact_repository_ref && automount_service_account_token == o.automount_service_account_token && dns_config == o.dns_config && dns_policy == o.dns_policy && entrypoint == o.entrypoint && executor == o.executor && hooks == o.hooks && host_aliases == o.host_aliases && host_network == o.host_network && image_pull_secrets == o.image_pull_secrets && metrics == o.metrics && node_selector == o.node_selector && on_exit == o.on_exit && parallelism == o.parallelism && pod_disruption_budget == o.pod_disruption_budget && pod_gc == o.pod_gc && == o. && pod_priority == o.pod_priority && pod_priority_class_name == o.pod_priority_class_name && pod_spec_patch == o.pod_spec_patch && priority == o.priority && retry_strategy == o.retry_strategy && scheduler_name == o.scheduler_name && security_context == o.security_context && service_account_name == o.service_account_name && shutdown == o.shutdown && suspend == o.suspend && synchronization == o.synchronization && template_defaults == o.template_defaults && templates == o.templates && tolerations == o.tolerations && ttl_strategy == o.ttl_strategy && volume_claim_gc == o.volume_claim_gc && volume_claim_templates == o.volume_claim_templates && volumes == o.volumes && == o. && workflow_template_ref == o.workflow_template_ref end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 530 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = ArgoWorkflows.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
596 597 598 599 600 601 602 603 604 605 606 607 608 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 596 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 509 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
496 497 498 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 496 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
502 503 504 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 502 def hash [active_deadline_seconds, affinity, archive_logs, arguments, artifact_gc, artifact_repository_ref, automount_service_account_token, dns_config, dns_policy, entrypoint, executor, hooks, host_aliases, host_network, image_pull_secrets, metrics, node_selector, on_exit, parallelism, pod_disruption_budget, pod_gc, , pod_priority, pod_priority_class_name, pod_spec_patch, priority, retry_strategy, scheduler_name, security_context, service_account_name, shutdown, suspend, synchronization, template_defaults, templates, tolerations, ttl_strategy, volume_claim_gc, volume_claim_templates, volumes, , workflow_template_ref].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
434 435 436 437 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 434 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
576 577 578 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 576 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
582 583 584 585 586 587 588 589 590 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 582 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
570 571 572 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 570 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
441 442 443 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_spec.rb', line 441 def valid? true end |