Class: ArgoWorkflows::IoArgoprojWorkflowV1alpha1WorkflowStep
- Inherits:
-
Object
- Object
- ArgoWorkflows::IoArgoprojWorkflowV1alpha1WorkflowStep
- Defined in:
- lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb
Overview
WorkflowStep is a reference to a template to execute in a series of step
Instance Attribute Summary collapse
-
#_when ⇒ Object
When is an expression in which the step should conditionally execute.
-
#arguments ⇒ Object
Arguments hold arguments to the template.
-
#continue_on ⇒ Object
ContinueOn makes argo to proceed with the following step even if this step fails.
-
#hooks ⇒ Object
Hooks holds the lifecycle hook which is invoked at lifecycle of step, irrespective of the success, failure, or error status of the primary step.
-
#inline ⇒ Object
Inline is the template.
-
#name ⇒ Object
Name of the step.
-
#on_exit ⇒ Object
OnExit is a template reference which is invoked at the end of the template, irrespective of the success, failure, or error of the primary template.
-
#template ⇒ Object
Template is the name of the template to execute as the step.
-
#template_ref ⇒ Object
TemplateRef is the reference to the template resource to execute as the step.
-
#with_items ⇒ Object
WithItems expands a step into multiple parallel steps from the items in the list Note: The structure of WithItems is free-form, so we need "x-kubernetes-preserve-unknown-fields: true" in the validation schema.
-
#with_param ⇒ Object
WithParam expands a step into multiple parallel steps from the value in the parameter, which is expected to be a JSON list.
-
#with_sequence ⇒ Object
WithSequence expands a step into a numeric sequence.
Class Method Summary collapse
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.swagger_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1WorkflowStep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IoArgoprojWorkflowV1alpha1WorkflowStep
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 92 def initialize(attributes = {}) return unless attributes.is_a?(Hash) # convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| h[k.to_sym] = v } if attributes.has_key?(:'arguments') self.arguments = attributes[:'arguments'] end if attributes.has_key?(:'continueOn') self.continue_on = attributes[:'continueOn'] end if attributes.has_key?(:'hooks') if (value = attributes[:'hooks']).is_a?(Hash) self.hooks = value end end if attributes.has_key?(:'inline') self.inline = attributes[:'inline'] end if attributes.has_key?(:'name') self.name = attributes[:'name'] end if attributes.has_key?(:'onExit') self.on_exit = attributes[:'onExit'] end if attributes.has_key?(:'template') self.template = attributes[:'template'] end if attributes.has_key?(:'templateRef') self.template_ref = attributes[:'templateRef'] end if attributes.has_key?(:'when') self._when = attributes[:'when'] end if attributes.has_key?(:'withItems') if (value = attributes[:'withItems']).is_a?(Array) self.with_items = value end end if attributes.has_key?(:'withParam') self.with_param = attributes[:'withParam'] end if attributes.has_key?(:'withSequence') self.with_sequence = attributes[:'withSequence'] end end |
Instance Attribute Details
#_when ⇒ Object
When is an expression in which the step should conditionally execute
43 44 45 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 43 def _when @_when end |
#arguments ⇒ Object
Arguments hold arguments to the template
19 20 21 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 19 def arguments @arguments end |
#continue_on ⇒ Object
ContinueOn makes argo to proceed with the following step even if this step fails. Errors and Failed states can be specified
22 23 24 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 22 def continue_on @continue_on end |
#hooks ⇒ Object
Hooks holds the lifecycle hook which is invoked at lifecycle of step, irrespective of the success, failure, or error status of the primary step
25 26 27 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 25 def hooks @hooks end |
#inline ⇒ Object
Inline is the template. Template must be empty if this is declared (and vice-versa). Note: This struct is defined recursively, since the inline template can potentially contain steps/DAGs that also has an "inline" field. Kubernetes doesn’t allow recursive types, so we need "x-kubernetes-preserve-unknown-fields: true" in the validation schema.
28 29 30 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 28 def inline @inline end |
#name ⇒ Object
Name of the step
31 32 33 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 31 def name @name end |
#on_exit ⇒ Object
OnExit is a template reference which is invoked at the end of the template, irrespective of the success, failure, or error of the primary template. DEPRECATED: Use Hooks.Template instead.
34 35 36 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 34 def on_exit @on_exit end |
#template ⇒ Object
Template is the name of the template to execute as the step
37 38 39 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 37 def template @template end |
#template_ref ⇒ Object
TemplateRef is the reference to the template resource to execute as the step.
40 41 42 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 40 def template_ref @template_ref end |
#with_items ⇒ Object
WithItems expands a step into multiple parallel steps from the items in the list Note: The structure of WithItems is free-form, so we need "x-kubernetes-preserve-unknown-fields: true" in the validation schema.
46 47 48 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 46 def with_items @with_items end |
#with_param ⇒ Object
WithParam expands a step into multiple parallel steps from the value in the parameter, which is expected to be a JSON list.
49 50 51 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 49 def with_param @with_param end |
#with_sequence ⇒ Object
WithSequence expands a step into a numeric sequence
52 53 54 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 52 def with_sequence @with_sequence end |
Class Method Details
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 55 def self.attribute_map { :'arguments' => :'arguments', :'continue_on' => :'continueOn', :'hooks' => :'hooks', :'inline' => :'inline', :'name' => :'name', :'on_exit' => :'onExit', :'template' => :'template', :'template_ref' => :'templateRef', :'_when' => :'when', :'with_items' => :'withItems', :'with_param' => :'withParam', :'with_sequence' => :'withSequence' } end |
.swagger_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 73 def self.swagger_types { :'arguments' => :'IoArgoprojWorkflowV1alpha1Arguments', :'continue_on' => :'IoArgoprojWorkflowV1alpha1ContinueOn', :'hooks' => :'Hash<String, IoArgoprojWorkflowV1alpha1LifecycleHook>', :'inline' => :'IoArgoprojWorkflowV1alpha1Template', :'name' => :'String', :'on_exit' => :'String', :'template' => :'String', :'template_ref' => :'IoArgoprojWorkflowV1alpha1TemplateRef', :'_when' => :'String', :'with_items' => :'Array<IoArgoprojWorkflowV1alpha1Item>', :'with_param' => :'String', :'with_sequence' => :'IoArgoprojWorkflowV1alpha1Sequence' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && arguments == o.arguments && continue_on == o.continue_on && hooks == o.hooks && inline == o.inline && name == o.name && on_exit == o.on_exit && template == o.template && template_ref == o.template_ref && _when == o._when && with_items == o.with_items && with_param == o.with_param && with_sequence == o.with_sequence end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 219 def _deserialize(type, value) case type.to_sym when :DateTime DateTime.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :BOOLEAN if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model temp_model = ArgoWorkflows.const_get(type).new temp_model.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 285 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 198 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.swagger_types.each_pair do |key, type| if type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end # or else data not found in attributes(hash), not an issue as the data can be optional end self end |
#eql?(o) ⇒ Boolean
185 186 187 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 185 def eql?(o) self == o end |
#hash ⇒ Fixnum
Calculates hash code according to all attributes.
191 192 193 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 191 def hash [arguments, continue_on, hooks, inline, name, on_exit, template, template_ref, _when, with_items, with_param, with_sequence].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 153 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
265 266 267 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 265 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) next if value.nil? hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 259 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 |
# File 'lib/argo_workflows/models/io_argoproj_workflow_v1alpha1_workflow_step.rb', line 160 def valid? true end |